==> haskell-text-conversions-0.3.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-conversions
version: 0.3.0
id: text-conversions-0.3.0-63jRCtEMxXNDrq0PUqx7ZQ
key: text-conversions-0.3.0-63jRCtEMxXNDrq0PUqx7ZQ
license: ISC
maintainer: lexi.lambda@gmail.com
author: Alexis King
homepage: https://github.com/cjdev/text-conversions#readme
synopsis: Safe conversions between textual types
description:
    Safe conversions between textual types
category: Data
abi: c7d5e9f451d06ef1a9edb3a1fbb5210d
exposed: True
exposed-modules:
    Data.Text.Conversions
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-conversions-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-conversions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-conversions-0.3.0
hs-libraries: HStext-conversions-0.3.0-63jRCtEMxXNDrq0PUqx7ZQ
depends:
    base-4.12.0.0 base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 errors-2.3.0-LXmLcZToQq8LQfNPeVO9nV
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock
haddock-html: /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-conversions-0.3.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-conversions
version: 0.3.0
id: text-conversions-0.3.0-FwUU2REY9R1RiDdvaSZqv
key: text-conversions-0.3.0-FwUU2REY9R1RiDdvaSZqv
license: ISC
maintainer: lexi.lambda@gmail.com
author: Alexis King
homepage: https://github.com/cjdev/text-conversions#readme
synopsis: Safe conversions between textual types
description:
    Safe conversions between textual types
category: Data
abi: 86211c32e78e4ce787b7092dc2708cdf
exposed: True
exposed-modules:
    Data.Text.Conversions
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-conversions-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-conversions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-conversions-0.3.0
hs-libraries: HStext-conversions-0.3.0-FwUU2REY9R1RiDdvaSZqv
depends:
    base-4.12.0.0 base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-2qZIU8NhrUrEe5vir8mbZ5
    bytestring-0.10.8.2 errors-2.3.0-DKQ2z6XIfxMIPXQp3usXDd
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock
haddock-html: /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
